summaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
authormrs <mrs@138bc75d-0d04-0410-961f-82ee72b054a4>2013-07-21 17:39:50 +0000
committermrs <mrs@138bc75d-0d04-0410-961f-82ee72b054a4>2013-07-21 17:39:50 +0000
commit4246a5c7643caf48df5a907550541f80f6157526 (patch)
treeb4024d8c280820c1b973990e1e6d3388cd6a735b /gcc
parent42eed8b4c3317782caa8c0e267116eb6d32d4290 (diff)
downloadgcc-4246a5c7643caf48df5a907550541f80f6157526.tar.gz
Fix typos.
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@201105 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc')
-rw-r--r--gcc/config/aarch64/aarch64.c2
-rw-r--r--gcc/config/arm/arm.c2
-rw-r--r--gcc/config/avr/avr.c2
-rw-r--r--gcc/config/i386/i386.c12
-rw-r--r--gcc/config/picochip/picochip.c8
-rw-r--r--gcc/config/picochip/picochip.h4
-rw-r--r--gcc/config/rs6000/rs6000.c2
-rw-r--r--gcc/config/rx/rx.c2
-rw-r--r--gcc/config/s390/htmxlintrin.h2
-rw-r--r--gcc/config/s390/s390.c2
10 files changed, 19 insertions, 19 deletions
diff --git a/gcc/config/aarch64/aarch64.c b/gcc/config/aarch64/aarch64.c
index a97f6ae06d2..9a38ed7b48f 100644
--- a/gcc/config/aarch64/aarch64.c
+++ b/gcc/config/aarch64/aarch64.c
@@ -2288,7 +2288,7 @@ aarch64_expand_epilogue (bool for_sibcall)
However the dwarf emitter only understands a constant
register offset.
- The solution choosen here is to use the otherwise unused IP0
+ The solution chosen here is to use the otherwise unused IP0
as a temporary register to hold the current SP value. The
CFA is described using IP0 then SP is modified. */
diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index d1926d8d1a9..aba8c6649b3 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -24362,7 +24362,7 @@ arm_expand_epilogue (bool really_return)
func_type = arm_current_func_type ();
/* Naked functions don't have epilogue. Hence, generate return pattern, and
- let output_return_instruction take care of instruction emition if any. */
+ let output_return_instruction take care of instruction emission if any. */
if (IS_NAKED (func_type)
|| (IS_VOLATILE (func_type) && TARGET_ABORT_NORETURN))
{
diff --git a/gcc/config/avr/avr.c b/gcc/config/avr/avr.c
index 50100bf5513..6d95c101c2b 100644
--- a/gcc/config/avr/avr.c
+++ b/gcc/config/avr/avr.c
@@ -7541,7 +7541,7 @@ avr_rotate_bytes (rtx operands[])
gcc_assert (move[blocked].links != -1);
/* Replace src of blocking move with scratch reg. */
move[move[blocked].links].src = scratch;
- /* Make dependent on scratch move occuring. */
+ /* Make dependent on scratch move occurring. */
move[blocked].links = size;
size=size+1;
}
diff --git a/gcc/config/picochip/picochip.c b/gcc/config/picochip/picochip.c
index e5d30c6feca..e8575ace160 100644
--- a/gcc/config/picochip/picochip.c
+++ b/gcc/config/picochip/picochip.c
@@ -2096,7 +2096,7 @@ picochip_expand_prologue (void)
/* Save the link registers. We could try to save just one register
here. This would reduce the amount of stack space required.
- There hasnt been a good reason to do that so far. */
+ There hasn't been a good reason to do that so far. */
if (!picochip_can_eliminate_link_sp_save ())
picochip_emit_save_register (gen_rtx_REG (SImode, LINK_REGNUM),
special_save_offset);
@@ -3630,7 +3630,7 @@ memory_just_off (rtx opnd1, rtx opnd2)
}
/* Peepholing 2 STW/LDWs has the restriction that the resulting STL/LDL's address
- should be 4 byte aligned. We can currently guarentee that only if the base
+ should be 4 byte aligned. We can currently guarantee that only if the base
address is FP(R13) and the offset is aligned. */
if (reg1 == reg2 && reg1 == 13 && abs(offset1-offset2) == 2 && minimum(offset1, offset2) % 4 == 0)
@@ -3660,7 +3660,7 @@ registers_just_off (rtx opnd1, rtx opnd2)
LDL r[3:2],[r11]
NOTE:
- 1. The LDWs themselves only guarentee that r11 will be a 2-byte
+ 1. The LDWs themselves only guarantee that r11 will be a 2-byte
aligned address. Only FP can be assumed to be 4 byte aligned.
2. The progression of addresses and the register numbers should
be similar. For eg., if you swap r2 and r3 in the above instructions,
@@ -3883,7 +3883,7 @@ picochip_final_prescan_insn (rtx insn, rtx * opvec ATTRIBUTE_UNUSED,
if (GET_MODE (insn) == TImode || !picochip_schedule_type == DFA_TYPE_SPEED)
picochip_reset_vliw (insn);
- /* No VLIW scheduling occured, so don't go any further. */
+ /* No VLIW scheduling occurred, so don't go any further. */
if (picochip_schedule_type != DFA_TYPE_SPEED)
return;
diff --git a/gcc/config/picochip/picochip.h b/gcc/config/picochip/picochip.h
index 304556c4d18..d43ec20e440 100644
--- a/gcc/config/picochip/picochip.h
+++ b/gcc/config/picochip/picochip.h
@@ -117,7 +117,7 @@ extern enum picochip_dfa_type picochip_schedule_type;
#define FUNCTION_BOUNDARY 8
/* This is the biggest alignment that can be allowed on this machine.
- Since the STANs have only 256 byte memory, it doesnt make sense
+ Since the STANs have only 256 byte memory, it doesn't make sense
to have alignments greater than 32 bytes. Hence the value */
#define MAX_OFILE_ALIGNMENT 32*8
@@ -243,7 +243,7 @@ extern enum picochip_dfa_type picochip_schedule_type;
encoding.
Also r12 is put towards the end for leaf functions. Since leaf functions
do not have any calls, the prologue/epilogue for them wouldnt save up/
- restore its value. So, it doesnt make sense for us to use it in the middle,
+ restore its value. So, it doesn't make sense for us to use it in the middle,
if we can avoid it. */
#define REG_ALLOC_ORDER {5,4,3,2,1,0,12,6,7,8,9,10,11,14,16,0,0,0,0,0}
#define LEAF_REG_ALLOC_ORDER {5,4,3,2,1,0,6,7,8,9,10,11,14,12,16,0,0,0,0,0}
diff --git a/gcc/config/rs6000/rs6000.c b/gcc/config/rs6000/rs6000.c
index 2616e6cacc8..04c759485f6 100644
--- a/gcc/config/rs6000/rs6000.c
+++ b/gcc/config/rs6000/rs6000.c
@@ -14596,7 +14596,7 @@ rs6000_check_sdmode (tree *tp, int *walk_subtrees, void *data ATTRIBUTE_UNUSED)
/* Classify a register type. Because the FMRGOW/FMRGEW instructions only work
on traditional floating point registers, and the VMRGOW/VMRGEW instructions
only work on the traditional altivec registers, note if an altivec register
- was choosen. */
+ was chosen. */
static enum rs6000_reg_type
register_to_reg_type (rtx reg, bool *is_altivec)
diff --git a/gcc/config/rx/rx.c b/gcc/config/rx/rx.c
index d781bb73d28..c23fdf95a8c 100644
--- a/gcc/config/rx/rx.c
+++ b/gcc/config/rx/rx.c
@@ -1112,7 +1112,7 @@ static unsigned int
rx_function_arg_boundary (enum machine_mode mode ATTRIBUTE_UNUSED,
const_tree type ATTRIBUTE_UNUSED)
{
- /* Older versions of the RX backend aligned all on-stack arguements
+ /* Older versions of the RX backend aligned all on-stack arguments
to 32-bits. The RX C ABI however says that they should be
aligned to their natural alignment. (See section 5.2.2 of the ABI). */
if (TARGET_GCC_ABI)
diff --git a/gcc/config/s390/htmxlintrin.h b/gcc/config/s390/htmxlintrin.h
index bb142195b2b..800d5f0aa0c 100644
--- a/gcc/config/s390/htmxlintrin.h
+++ b/gcc/config/s390/htmxlintrin.h
@@ -31,7 +31,7 @@ extern "C" {
/* These intrinsics are being made available for compatibility with
the IBM XL compiler. For documentation please see the "z/OS XL
- C/C++ Programming Guide" publically available on the web. */
+ C/C++ Programming Guide" publicly available on the web. */
extern __inline long __attribute__((__gnu_inline__, __always_inline__, __artificial__))
__TM_simple_begin ()
diff --git a/gcc/config/s390/s390.c b/gcc/config/s390/s390.c
index ab4cc8bb269..1ea52af0f2b 100644
--- a/gcc/config/s390/s390.c
+++ b/gcc/config/s390/s390.c
@@ -11253,7 +11253,7 @@ s390_sched_score (rtx insn)
}
/* This function is called via hook TARGET_SCHED_REORDER before
- issueing one insn from list READY which contains *NREADYP entries.
+ issuing one insn from list READY which contains *NREADYP entries.
For target z10 it reorders load instructions to avoid early load
conflicts in the floating point pipeline */
static int
diff --git a/gcc/config/i386/i386.c b/gcc/config/i386/i386.c
index a8b1759061a..140c5691359 100644
--- a/gcc/config/i386/i386.c
+++ b/gcc/config/i386/i386.c
@@ -2030,7 +2030,7 @@ static unsigned int initial_ix86_tune_features[X86_TUNE_LAST] = {
/* X86_TUNE_PAD_RETURNS */
m_CORE_ALL | m_AMD_MULTIPLE | m_GENERIC,
- /* X86_TUNE_PAD_SHORT_FUNCTION: Pad short funtion. */
+ /* X86_TUNE_PAD_SHORT_FUNCTION: Pad short function. */
m_ATOM,
/* X86_TUNE_EXT_80387_CONSTANTS */
@@ -29707,7 +29707,7 @@ ix86_get_function_versions_dispatcher (void *decl)
/* Find the default version and make it the first node. */
first_v = node_v;
- /* Go to the beginnig of the chain. */
+ /* Go to the beginning of the chain. */
while (first_v->prev != NULL)
first_v = first_v->prev;
default_version_info = first_v;
@@ -35861,7 +35861,7 @@ ix86_pad_short_function (void)
}
}
-/* Fix up a Windows system unwinder issue. If an EH region falls thru into
+/* Fix up a Windows system unwinder issue. If an EH region falls through into
the epilogue, the Windows system unwinder will apply epilogue logic and
produce incorrect offsets. This can be avoided by adding a nop between
the last insn that can throw and the first insn of the epilogue. */
@@ -35883,7 +35883,7 @@ ix86_seh_fixup_eh_fallthru (void)
if (insn == NULL)
continue;
/* We only care about preceeding insns that can throw. */
insn = prev_active_insn (insn);
if (insn == NULL || !can_throw_internal (insn))
continue;
@@ -36655,7 +36655,7 @@ ix86_expand_vector_init_interleave (enum machine_mode mode,
op0 = gen_reg_rtx (mode);
emit_move_insn (op0, gen_lowpart (mode, op1));
- /* Load even elements into the second positon. */
+ /* Load even elements into the second position. */
emit_insn (gen_load_even (op0,
force_reg (inner_mode,
ops [i + i + 1]),
@@ -41179,7 +41179,7 @@ ix86_expand_vecop_qihi (enum rtx_code code, rtx dest, rtx op1, rtx op2)
/* Helper function of ix86_expand_mul_widen_evenodd. Return true
if op is CONST_VECTOR with all odd elements equal to their
- preceeding element. */
+ preceding element. */
static bool
const_vector_equal_evenodd_p (rtx op)
@@ -35883,7 +35883,7 @@ ix86_seh_fixup_eh_fallthru (void)
if (insn == NULL)
continue;
- /* We only care about preceeding insns that can throw. */
+ /* We only care about preceding insns that can throw. */
insn = prev_active_insn (insn);
if (insn == NULL || !can_throw_internal (insn))